@@ -26,23 +26,23 @@ typedef struct dbase_policydb dbase_t;
 struct dbase_policydb {
 
 	/* Backing file suffix */
-	const char* suffix;
+	const char *suffix;
 
 	/* Base record table */
-	record_table_t* rtable;
+	record_table_t *rtable;
 
 	/* Policy extensions */
-	record_policydb_table_t* rptable;
+	record_policydb_table_t *rptable;
 
-	sepol_policydb_t* policydb;
+	sepol_policydb_t *policydb;
 
 	int cache_serial;
 	int modified;
 	int attached;
 };
 
-static void dbase_policydb_drop_cache(
-	dbase_policydb_t* dbase) {
+static void dbase_policydb_drop_cache(dbase_policydb_t * dbase)
+{
 
 	if (dbase->cache_serial >= 0) {
 		sepol_policydb_free(dbase->policydb);
@@ -51,9 +51,9 @@ static void dbase_policydb_drop_cache(
 	}
 }
 
-static int dbase_policydb_set_serial(
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase) {
+static int dbase_policydb_set_serial(semanage_handle_t * handle,
+				     dbase_policydb_t * dbase)
+{
 
 	int cache_serial = handle->funcs->get_serial(handle);
 	if (cache_serial < 0) {
@@ -65,15 +65,15 @@ static int dbase_policydb_set_serial(
 	return STATUS_SUCCESS;
 }
 
-static int dbase_policydb_needs_resync(
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase) {
+static int dbase_policydb_needs_resync(semanage_handle_t * handle,
+				       dbase_policydb_t * dbase)
+{
 
 	int cache_serial;
 
 	if (dbase->cache_serial < 0)
 		return 1;
-		
+
 	cache_serial = handle->funcs->get_serial(handle);
 	if (cache_serial < 0)
 		return 1;
@@ -86,18 +86,17 @@ static int dbase_policydb_needs_resync(
 	return 0;
 }
 
-static int construct_filename(
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	char** filename) {
+static int construct_filename(semanage_handle_t * handle,
+			      dbase_policydb_t * dbase, char **filename)
+{
 
-	const char* path = (handle->is_in_transaction)?
-		semanage_path(SEMANAGE_TMP, SEMANAGE_TOPLEVEL):
-		semanage_path(SEMANAGE_ACTIVE, SEMANAGE_TOPLEVEL);
+	const char *path = (handle->is_in_transaction) ?
+	    semanage_path(SEMANAGE_TMP, SEMANAGE_TOPLEVEL) :
+	    semanage_path(SEMANAGE_ACTIVE, SEMANAGE_TOPLEVEL);
 	size_t fname_length = strlen(path) + strlen(dbase->suffix) + 2;
 
-	char* fname = malloc(fname_length);
-	if (!fname) { 
+	char *fname = malloc(fname_length);
+	if (!fname) {
 		ERR(handle, "out of memory, could not construct database name");
 		return STATUS_ERR;
 	}
@@ -107,14 +106,14 @@ static int construct_filename(
 	return STATUS_SUCCESS;
 }
 
-static int dbase_policydb_cache(
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase) {
+static int dbase_policydb_cache(semanage_handle_t * handle,
+				dbase_policydb_t * dbase)
+{
 
-	FILE* fp = NULL;
-	sepol_policydb_t* policydb = NULL;
-	sepol_policy_file_t* pf = NULL;
-	char* fname = NULL;
+	FILE *fp = NULL;
+	sepol_policydb_t *policydb = NULL;
+	sepol_policy_file_t *pf = NULL;
+	char *fname = NULL;
 
 	/* Check if cache is needed */
 	if (dbase->attached)
@@ -122,8 +121,8 @@ static int dbase_policydb_cache(
 
 	if (!dbase_policydb_needs_resync(handle, dbase))
 		return STATUS_SUCCESS;
-	
-	if (construct_filename(handle, dbase, &fname) < 0) 
+
+	if (construct_filename(handle, dbase, &fname) < 0)
 		goto err;
 
 	if (sepol_policydb_create(&policydb) < 0) {
@@ -136,10 +135,10 @@ static int dbase_policydb_cache(
 	fp = fopen(fname, "rb");
 	if (fp == NULL && errno != ENOENT) {
 		ERR(handle, "could not open %s for reading: %s",
-			fname, strerror(errno));
+		    fname, strerror(errno));
 		goto err;
 	}
-	
+
 	/* If the file was opened successfully, read a policydb */
 	if (fp != NULL) {
 		__fsetlocking(fp, FSETLOCKING_BYCALLER);
@@ -156,18 +155,19 @@ static int dbase_policydb_cache(
 
 		sepol_policy_file_free(pf);
 		fclose(fp);
+		fp = NULL;
 	}
 
 	/* Update cache serial */
 	if (dbase_policydb_set_serial(handle, dbase) < 0)
 		goto err;
 
-	/* Update the database policydb */	
+	/* Update the database policydb */
 	dbase->policydb = policydb;
 	free(fname);
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not cache policy database");
 	if (fp)
 		fclose(fp);
@@ -177,9 +177,9 @@ static int dbase_policydb_cache(
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_flush(
-	semanage_handle_t* handle,	
-	dbase_policydb_t* dbase) {
+static int dbase_policydb_flush(semanage_handle_t * handle,
+				dbase_policydb_t * dbase)
+{
 
 	if (!dbase->modified)
 		return STATUS_SUCCESS;
@@ -192,21 +192,21 @@ static int dbase_policydb_flush(
 }
 
 /* Check if modified */
-static int dbase_policydb_is_modified(
-	dbase_policydb_t* dbase) {
+static int dbase_policydb_is_modified(dbase_policydb_t * dbase)
+{
 
 	return dbase->modified;
 }
 
-int dbase_policydb_init(
-	semanage_handle_t* handle,
-	const char* suffix,
-	record_table_t* rtable,
-	record_policydb_table_t* rptable,
-        dbase_policydb_t** dbase) {
+int dbase_policydb_init(semanage_handle_t * handle,
+			const char *suffix,
+			record_table_t * rtable,
+			record_policydb_table_t * rptable,
+			dbase_policydb_t ** dbase)
+{
 
-	dbase_policydb_t* tmp_dbase =
-		(dbase_policydb_t*) malloc(sizeof(dbase_policydb_t));
+	dbase_policydb_t *tmp_dbase =
+	    (dbase_policydb_t *) malloc(sizeof(dbase_policydb_t));
 
 	if (!tmp_dbase)
 		goto omem;
@@ -222,7 +222,7 @@ int dbase_policydb_init(
 
 	return STATUS_SUCCESS;
 
-	omem:
+      omem:
 	ERR(handle, "out of memory, could not initialize policy database");
 	free(tmp_dbase);
 
@@ -230,8 +230,8 @@ int dbase_policydb_init(
 }
 
 /* Release dbase resources */
-void dbase_policydb_release(
-	dbase_policydb_t* dbase) {
+void dbase_policydb_release(dbase_policydb_t * dbase)
+{
 
 	dbase_policydb_drop_cache(dbase);
 	free(dbase);
@@ -241,9 +241,9 @@ void dbase_policydb_release(
  * This implies drop_cache(),
  * and prevents flush() and drop_cache()
  * until detached. */
-void dbase_policydb_attach(
-        dbase_policydb_t* dbase,
-        sepol_policydb_t* policydb) {
+void dbase_policydb_attach(dbase_policydb_t * dbase,
+			   sepol_policydb_t * policydb)
+{
 
 	dbase->attached = 1;
 	dbase_policydb_drop_cache(dbase);
@@ -252,71 +252,67 @@ void dbase_policydb_attach(
 
 /* Detach from a shared policdb.
  * This implies drop_cache. */
-void dbase_policydb_detach(
-	dbase_policydb_t* dbase) {
+void dbase_policydb_detach(dbase_policydb_t * dbase)
+{
 
 	dbase->attached = 0;
 	dbase->modified = 0;
 }
 
-static int dbase_policydb_add (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	const record_key_t* key,
-	const record_t* data) {
-	
-	if (dbase->rptable->add(handle->sepolh,	
-		dbase->policydb, key, data) < 0)
+static int dbase_policydb_add(semanage_handle_t * handle,
+			      dbase_policydb_t * dbase,
+			      const record_key_t * key, const record_t * data)
+{
+
+	if (dbase->rptable->add(handle->sepolh, dbase->policydb, key, data) < 0)
 		goto err;
 
 	dbase->modified = 1;
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not add record to the database");
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_set(
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	const record_key_t* key,
-	const record_t* data) {
+static int dbase_policydb_set(semanage_handle_t * handle,
+			      dbase_policydb_t * dbase,
+			      const record_key_t * key, const record_t * data)
+{
 
-	if (dbase->rptable->set(handle->sepolh, 
-		dbase->policydb, key, data) < 0)
+	if (dbase->rptable->set(handle->sepolh, dbase->policydb, key, data) < 0)
 		goto err;
 
 	dbase->modified = 1;
 	return STATUS_SUCCESS;
-		
-	err:
+
+      err:
 	ERR(handle, "could not set record value");
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_modify (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	const record_key_t* key,
-	const record_t* data) {
+static int dbase_policydb_modify(semanage_handle_t * handle,
+				 dbase_policydb_t * dbase,
+				 const record_key_t * key,
+				 const record_t * data)
+{
 
-	if (dbase->rptable->modify(handle->sepolh, 
-		dbase->policydb, key, data) < 0)
+	if (dbase->rptable->modify(handle->sepolh,
+				   dbase->policydb, key, data) < 0)
 		goto err;
 
 	dbase->modified = 1;
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not modify record value");
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_del (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	const record_key_t* key) {
+static int dbase_policydb_del(semanage_handle_t * handle,
+			      dbase_policydb_t * dbase,
+			      const record_key_t * key)
+{
 
 	/* Stub */
 	key = NULL;
@@ -325,9 +321,9 @@ static int dbase_policydb_del (
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_clear (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase) {
+static int dbase_policydb_clear(semanage_handle_t * handle,
+				dbase_policydb_t * dbase)
+{
 
 	/* Stub */
 	handle = NULL;
@@ -335,123 +331,118 @@ static int dbase_policydb_clear (
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_query (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	const record_key_t* key,
-	record_t** response) {
+static int dbase_policydb_query(semanage_handle_t * handle,
+				dbase_policydb_t * dbase,
+				const record_key_t * key, record_t ** response)
+{
 
 	if (dbase->rptable->query(handle->sepolh,
-		dbase->policydb, key, response) < 0)
+				  dbase->policydb, key, response) < 0)
 		goto err;
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not query record value");
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_exists (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	const record_key_t* key,
-	int* response) {
+static int dbase_policydb_exists(semanage_handle_t * handle,
+				 dbase_policydb_t * dbase,
+				 const record_key_t * key, int *response)
+{
 
-	if (dbase->rptable->exists(handle->sepolh, 
-		dbase->policydb, key, response) < 0)
+	if (dbase->rptable->exists(handle->sepolh,
+				   dbase->policydb, key, response) < 0)
 		goto err;
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not check if record exists");
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_count (
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	unsigned int* response) {
+static int dbase_policydb_count(semanage_handle_t * handle,
+				dbase_policydb_t * dbase,
+				unsigned int *response)
+{
 
 	if (dbase->rptable->count(handle->sepolh,
-		dbase->policydb, response) < 0)
+				  dbase->policydb, response) < 0)
 		goto err;
 
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not count the database records");
 	return STATUS_ERR;
 }
 
-static int dbase_policydb_iterate(
-	semanage_handle_t* handle,
-	dbase_policydb_t* dbase,
-	int (*fn) (
-		const record_t* record, 
-		void* fn_arg),
-	void* arg) {
+static int dbase_policydb_iterate(semanage_handle_t * handle,
+				  dbase_policydb_t * dbase,
+				  int (*fn) (const record_t * record,
+					     void *fn_arg), void *arg)
+{
 
 	if (dbase->rptable->iterate(handle->sepolh,
-		dbase->policydb, fn, arg) < 0) 
+				    dbase->policydb, fn, arg) < 0)
 		goto err;
 
-        return STATUS_SUCCESS;
+	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not iterate over records");
 	return STATUS_ERR;
 }
 
 struct list_handler_arg {
-	semanage_handle_t* handle;
-	record_table_t* rtable;
-	record_t** records;
+	semanage_handle_t *handle;
+	record_table_t *rtable;
+	record_t **records;
 	int pos;
 };
 
-static int list_handler(
-	const record_t* record,
-	void* varg) {
+static int list_handler(const record_t * record, void *varg)
+{
 
-	struct list_handler_arg* arg = 
-		(struct list_handler_arg*) varg;
+	struct list_handler_arg *arg = (struct list_handler_arg *)varg;
 
-	if (arg->rtable->clone(arg->handle, record, &arg->records[arg->pos]) < 0)
+	if (arg->rtable->clone(arg->handle, record, &arg->records[arg->pos]) <
+	    0)
 		return -1;
 	arg->pos++;
 	return 0;
 }
 
-static int dbase_policydb_list (
-	semanage_handle_t* handle,
-	dbase_t* dbase,
-	record_t*** records,
-	unsigned int* count) {
+static int dbase_policydb_list(semanage_handle_t * handle,
+			       dbase_t * dbase,
+			       record_t *** records, unsigned int *count)
+{
 
-	record_t** tmp_records = NULL;
+	record_t **tmp_records = NULL;
 	unsigned int tmp_count;
 	struct list_handler_arg list_arg;
 	list_arg.pos = 0;
 	list_arg.rtable = dbase->rtable;
 	list_arg.handle = handle;
 
-	if (dbase->rptable->count(handle->sepolh, 
-		dbase->policydb, &tmp_count) < 0)
+	if (dbase->rptable->count(handle->sepolh,
+				  dbase->policydb, &tmp_count) < 0)
 		goto err;
 
 	if (tmp_count > 0) {
-		tmp_records = (record_t**)
-			calloc(tmp_count, sizeof (record_t*));
+		tmp_records = (record_t **)
+		    calloc(tmp_count, sizeof(record_t *));
 
 		if (tmp_records == NULL)
 			goto omem;
 
 		list_arg.records = tmp_records;
-		
+
 		if (dbase->rptable->iterate(handle->sepolh,
-			dbase->policydb, list_handler, &list_arg) < 0) {
+					    dbase->policydb, list_handler,
+					    &list_arg) < 0) {
 			ERR(handle, "list handler could not extract record");
 			goto err;
 		}
@@ -461,10 +452,10 @@ static int dbase_policydb_list (
 	*count = tmp_count;
 	return STATUS_SUCCESS;
 
-	omem:
+      omem:
 	ERR(handle, "out of memory");
 
-	err:
+      err:
 	for (; list_arg.pos >= 0; list_arg.pos--)
 		dbase->rtable->free(tmp_records[list_arg.pos]);
 	free(tmp_records);
@@ -472,8 +463,8 @@ static int dbase_policydb_list (
 	return STATUS_ERR;
 }
 
-static record_table_t* dbase_policydb_get_rtable(
-	dbase_policydb_t* dbase) {
+static record_table_t *dbase_policydb_get_rtable(dbase_policydb_t * dbase)
+{
 
 	return dbase->rtable;
 }
@@ -495,7 +486,7 @@ dbase_table_t SEMANAGE_POLICYDB_DTABLE = {
 	.set = dbase_policydb_set,
 	.del = dbase_policydb_del,
 	.clear = dbase_policydb_clear,
-	.modify = dbase_policydb_modify, 
+	.modify = dbase_policydb_modify,
 	.query = dbase_policydb_query,
 	.count = dbase_policydb_count,
 
