@@ -23,6 +23,8 @@
 #include <stdarg.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <errno.h>
+#include <string.h>
 #include "handle.h"
 #include "debug.h"
 
@@ -55,10 +57,12 @@ void hidden semanage_msg_default_handler(void *varg,
 {
 
 	FILE *stream = NULL;
+	int errsv = 0;
 
 	switch (semanage_msg_get_level(handle)) {
 
 	case SEMANAGE_MSG_ERR:
+		errsv = errno;
 	case SEMANAGE_MSG_WARN:
 		stream = stderr;
 		break;
@@ -77,6 +81,9 @@ void hidden semanage_msg_default_handler(void *varg,
 	vfprintf(stream, fmt, ap);
 	va_end(ap);
 
+	if (errsv && errsv != ENOMEM)
+		fprintf(stream, " (%s).", strerror(errsv));
+
 	fprintf(stream, "\n");
 
 	varg = NULL;
