@@ -31,11 +31,9 @@ struct semanage_direct_handle {
 	int translock_file_fd;
 };
 
-int semanage_direct_connect(
-	struct semanage_handle *sh);
+int semanage_direct_connect(struct semanage_handle *sh);
 
-int semanage_direct_is_managed(
-	struct semanage_handle *sh);
+int semanage_direct_is_managed(struct semanage_handle *sh);
 
 int semanage_direct_access_check(struct semanage_handle *sh);
 
