@@ -32,41 +32,40 @@ struct semanage_policy_table {
 
 	/* Returns the current policy serial/commit number
 	 * A negative number is returned in case of failre */
-	int (*get_serial)(struct semanage_handle*);
+	int (*get_serial) (struct semanage_handle *);
 
-	/* Destroy a connection */	
-        void (*destroy)(struct semanage_handle*);
+	/* Destroy a connection */
+	void (*destroy) (struct semanage_handle *);
 
 	/* Disconnect from policy */
-        int (*disconnect)(struct semanage_handle*);
+	int (*disconnect) (struct semanage_handle *);
 
 	/* Begin a policy transaction */
-        int (*begin_trans)(struct semanage_handle*);
+	int (*begin_trans) (struct semanage_handle *);
 
 	/* Commit a policy transaction */
-        int (*commit)(struct semanage_handle*);
+	int (*commit) (struct semanage_handle *);
 
 	/* Install a policy module */
-        int (*install)(struct semanage_handle*, char *, size_t);
+	int (*install) (struct semanage_handle *, char *, size_t);
 
 	/* Upgrade a policy module */
-        int (*upgrade)(struct semanage_handle*, char *, size_t);
+	int (*upgrade) (struct semanage_handle *, char *, size_t);
 
 	/* Remove a policy module */
-	int (*remove)(struct semanage_handle*, char *);
+	int (*remove) (struct semanage_handle *, char *);
 
 	/* List policy modules */
-	int (*list)(struct semanage_handle*, semanage_module_info_t **, int *);
+	int (*list) (struct semanage_handle *, semanage_module_info_t **,
+		     int *);
 
 	/* Install base policy */
-        int (*install_base)(struct semanage_handle*, char *, size_t);
+	int (*install_base) (struct semanage_handle *, char *, size_t);
 };
 
 /* Should be backend independent */
-extern int semanage_base_merge_components(
-	struct semanage_handle* handle);
+extern int semanage_base_merge_components(struct semanage_handle *handle);
 
-extern int semanage_commit_components(
-	struct semanage_handle* handle);
+extern int semanage_commit_components(struct semanage_handle *handle);
 
 #endif
